@@ -1,22 +1,25 @@
 #ifndef NEWSBOAT_LOGGER_H_
 #define NEWSBOAT_LOGGER_H_
 
-#include "config.h"
+#include <cstdint>
+#include <string>
+#include <utility>
+
 #include "strprintf.h"
 
-#include "logger.rs.h"
+#include "libnewsboat-ffi/src/logger.rs.h" // IWYU pragma: export
 
 namespace newsboat {
 
-using Level = Logger::Level;
+using Level = logger::Level;
 
-namespace Logger {
+namespace logger {
 
 template<typename... Args>
-void log(Level l, const std::string& format, Args... args)
+void log(Level l, const std::string& format, Args&& ... args)
 {
 	if (l == Level::USERERROR || static_cast<int64_t>(l) <= get_loglevel()) {
-		log_internal(l, strprintf::fmt(format, args...));
+		log_internal(l, strprintf::fmt(format, std::forward<Args>(args)...));
 	}
 }
 };
@@ -31,7 +34,7 @@ void log(Level l, const std::string& format, Args... args)
 #else
 #define LOG(x, ...)                                        \
 	do {                                               \
-		newsboat::Logger::log(x, __VA_ARGS__); \
+		newsboat::logger::log(x, __VA_ARGS__); \
 	} while (0)
 #endif
 
