@@ -9,14 +9,14 @@ class RemoteApi;
 
 class RemoteApiUrlReader : public UrlReader {
 public:
-	RemoteApiUrlReader(const std::string& source_name, const std::string& url_file,
+	RemoteApiUrlReader(const std::string& source_name, const Filepath& url_file,
 		RemoteApi& api);
 	std::optional<utils::ReadTextFileError> reload() override;
 	std::string get_source() const override;
 
 private:
 	std::string source_name;
-	std::string file;
+	Filepath file;
 	RemoteApi& api;
 };
 
