@@ -6,10 +6,10 @@ use tempfile::TempDir;
 fn t_cliargsparser_dash_i_resolves_tilde_to_homedir() {
     let tmp = TempDir::new().unwrap();
 
-    env::set_var("HOME", tmp.path());
+    unsafe { env::set_var("HOME", tmp.path()) };
 
     let filename = "feedlist.opml";
-    let arg = format!("~/{}", filename);
+    let arg = format!("~/{filename}");
 
     let check = |opts| {
         let args = CliArgsParser::new(opts);
